Internal function

checkForExpressionSet(set, datasources = NULL)

Arguments

set

character Name of the object to look for on the study server

datasources

a list of DSConnection-class (default NULL) objects obtained after login

Value

No return object, only stops the execution if the object is not on the study server or if it's not an ExposomeSet