This function performs a non-disclosive Differential Gene Expression Analysis using DESeq2 package from Bioconductor.

ds.DESeq2(
  model,
  set,
  test = "Wald",
  fitType = "parametric",
  sfType = "ratio",
  reduced = NULL,
  contrast = NULL,
  datasources = NULL
)

Arguments

model

formula indicating the condition and other covariates to be ajusted

set

a RangedSummarizedExperiment object.

test

"Wald" or "LRT".

fitType

"parametric", "local", or "mean".

sfType

"ratio", "poscounts", or "iterate".

reduced

a reduced formula for test="LRT"

contrast

the comparison to extract from the object to build the results table

datasources

a list of DSConnection-class objects obtained after login. If the datasources argument is not specified the default set of connections will be used: see datashield.connections_default.

Value

Data frame containing the results of the Differential Gene Expression analysis

Details

Implementation of Bioconductor's DESeq2 in DataSHIELD infraestructure.

This function is similar to Bioconductor's DESeq2 package DESeq function.

Author

L. Abarrategui, for DataSHIELD development team