ds.RNAseqPreproc.RdDetermine which genes have sufficiently large counts to be retained in a statistical analysis.
This is a similar function to edgeR::filterByExpr
ds.RNAseqPreproc(object, group = NULL, newobj.name = NULL, datasources = NULL)character Name of the eSet, RangedSummarizedExperiment on the server
character indicating the vector or factor giving group membership (optional).
character (default NULL) Name to be assigned
on the server to the RangedSummarizedExperiment. If NULL the created RangedSummarizedExperiment will
be assigned to a variable named 'rse.filter'
a list of DSConnection-class (default NULL) objects obtained after login
This function does not have an output. It creates (or overwrites) a data frame on the study server.