ds.metaGWAS.RdPerforms GWAS using GENESIS
ds.metaGWAS(
genoData,
model,
family = "binomial",
snpBlock = 10000,
datasources = NULL,
...
)character vector of objects on the server side object which is a container for storing genotype data
from a GWAS toghether with the metadata associated with the subjects (i.e. phenotypes and/or covariates)
formula indicating the condition (left side) and other covariates to be adjusted for (i.e. condition ~ covar1 + ... + covar2). The fitted model is: snp ~ condition + covar1 + ... + covarN
A description of the generalized linear model used. The defatul is "binomial" that is defined for case/control studies. Quantitative traits can be analyzed by using "gaussian". Other values are accepted.
an integer specifying the number of SNPs in an iteration block. See GenotypeIterator
function in GWASTools package.
other arguments of fitNullModel function in GENESIS package
a matrix with SNPs ordered by p-values