Trimming methylation beta values to remove potential outliers. Trimming scheme is as follows: trim values beyond the lower and upper outer fences. These are defined by the `pct` argument.

ds.removeOutliers(object, pct = 0.125, newobj.name = NULL, datasources = NULL)

Arguments

object

character Name of an ExpressionSet or SummarizedExperiment / RangedSummarizedExperiment on the server side to which perform the filtering

pct

numeric (default 0.125) Tail and head quantiles that will be considered as outliers; for example: a pct=0.125 will use the function matrixStats::rowQuantiles(probs = c(0.125, 1-0.125)) to detect outliers.

newobj.name

character (default NULL) If provided, the filtered object will be assigned to a variable on the server with this name. If NULL, the input variable will be overwritten.

datasources

a list of DSConnection-class objects obtained after login.

Value

This function does not have an output. It creates (or overwrites) an ExpressionSet on the study server.