Interface to run SNPtest commands on a ssh connection (with SNPtest 2.5.2 installed)

ds.snptest(client, snptest.arguments, datasources = NULL)

Arguments

client

character Name of the ssh resource on the server

snptest.arguments

character SNPtest arguments, the leading "snptest" and trailing "-o output.out" do not need to be provided, they are handled on the server side.

datasources

a list of DSConnection-class (default NULL) objects obtained after login

Value

List containing:
- Results: Table of results (typical SNPtest output file)
- Output: Console output of the ssh query