ds.subsetExpressionSet.RdSubset ExpressionSet using a categorical variable of the covariates as filter. Can also subset by complete cases
ds.subsetExpressionSet(
eSet,
objective_variable = NULL,
objective_value = NULL,
complete_cases = FALSE,
newobj.name = NULL,
datasources = NULL
)character ExpressionSet to subset
character (default NULL) Name of the covariate on the ExpressionSet to use as filter
character (default NULL) Name of the value from the objective_variable to filter.
The resulting subset will be the individuals that match this value.
To put in in code, it can be represented as: subset <- expressionSet[expressionSet$objective_variable == objective_value,]
bool (default FALSE) If TRUE only the complete cases will be included on the subset.
This option can be used with objective_variable and objective_value or without them, if those arguments are not
present, the subset will be the complete cases of the whole ExpressionSet.
character (default NULL) Name of the subseted ExpressionSet. If NULL, the variable
"subsetted_ExpressionSet" will be used.
a list of DSConnection-class (default NULL) objects obtained after login
This function does not have an output. It creates (or overwrites) a data frame on the study server.