eafPlot.RdEAF plot
eafPlot(
x,
reference,
rs_x = "rs",
rs_reference,
freq_x = "freq",
freq_reference,
inverse_freq_x = T,
inverse_freq_reference = F
)data.frame / list of data.frames (output of ds.GWAS) Single table of results or list of tables
(default output of ds.GWAS).
data.frame Reference table that at least contains: SNP rs IDs and minor (or major)
allele frequency of reference.
character (default "rs") Name of the column that contains the rs IDs on x
character Name of the column that contains the rs IDs on reference
character (default "freq") Name of the column that contains the minor (or major)
allele frequencies on x
character Name of the column that contains the minor (or major)
allele frequencies on reference
bool (default TRUE) Use TRUE if x contains major allele
frequencies, use FALSE if x contains minor allele frequencies. The default is set to
TRUE since the default output of ds.GWAS frequencies is major allele frequencies.
bool (default FALSE) Use TRUE if x contains major allele
frequencies, use FALSE if x contains minor allele frequencies. The default is set to
TRUE since usually reference panels report minor allele frequencies.
A ggplot object
Plotting the reported EAFs against a reference set, such as from the HapMap or 1000 Genomes projects, or from one specific study, can help visualize patterns that pinpoint strand issues, allele miscoding or the inclusion of individuals whose self-reported ancestry did not match their genetic ancestry.