Plot the results of a ds.PCA()

plotPCA(object, group = NULL, xcomp = 1, ycomp = 2, datasources = NULL)

Arguments

group
xcomp

numeric Principal component to plot on the X axis

ycomp

numeric Principal component to plot on the Y axis

datasources
res

PCASNPS Object returned from ds.PCASNPS()

geno

Value

ggplot object