Plot the results of a ds.PCASNPS()

plotPCASNPS(res, group = NULL, xcomp = 1, ycomp = 2, datasources = NULL)

Arguments

res

PCASNPS Object returned from ds.PCASNPS()

group
xcomp

numeric Principal component to plot on the X axis

ycomp

numeric Principal component to plot on the Y axis

datasources
geno

Value

ggplot object