Assumptions:

- Expected P values are uniformly distributed.
- Confidence intervals assume independence between tests.
We expect deviations past the confidence intervals if the tests are not independent. For example, in a genome-wide association study, the genotype at any position is correlated to nearby positions. Tests of nearby genotypes will result in similar test statistics.

Creates a QQ-plot to visualize inflation

qqplot(ps, ci = 0.95)

Arguments

ps

Vector of p-values.

ci

Size of the confidence interval, 95% by default.

Value

A ggplot2 plot.