SE-N Plot

seNPlot(x, se_column = "Est.SE", n_column = "n.obs")

Arguments

x

list of data.frames (output of ds.GWAS) List of tables (default output of ds.GWAS).

se_column

character (default "Est.SE") Name of the column containing the SE.

n_column

character (default "n.obs") Name of the column containing the number of observations.

Value

A ggplot object

Details

Plot to reveal issues with trait transformations. A collection of studies with no issues will fall on a line.