checkForExpressionSet.RdInternal function
checkForExpressionSet(set, datasources = NULL)character Name of the object to look for on the study server
a list of DSConnection-class (default NULL) objects obtained after login
No return object, only stops the execution if the object is not on the study server or if it's not an ExposomeSet