ds.DESeq2.RdThis function performs a non-disclosive
Differential Gene Expression Analysis using DESeq2 package
from Bioconductor.
ds.DESeq2(
model,
set,
test = "Wald",
fitType = "parametric",
sfType = "ratio",
reduced = NULL,
contrast = NULL,
datasources = NULL
)formula indicating the condition and other covariates to be ajusted
a RangedSummarizedExperiment object.
"Wald" or "LRT".
"parametric", "local", or "mean".
"ratio", "poscounts", or "iterate".
a reduced formula for test="LRT"
the comparison to extract from the object to build the results table
a list of DSConnection-class objects obtained after login.
If the datasources argument is not specified
the default set of connections will be used: see datashield.connections_default.
Data frame containing the results of the Differential Gene Expression analysis
Implementation of Bioconductor's DESeq2 in DataSHIELD
infraestructure.
This function is similar to Bioconductor's
DESeq2 package DESeq function.