ds.PCA.RdPCA for genotype data on the study server
ds.PCA(
genoData,
snp_subset = TRUE,
standardize = TRUE,
ncomp = 5L,
datasources = NULL
)character Name of the GenotypeData object on the server
bool (default TRUE) Use only SNPs that have been linked to ethnic groups
bool (default TRUE) Standardize the genotype data before performing the analysis
integer (default 5L) Number of principal components to compute
a list of DSConnection-class objects obtained after login
Returns list with the names of the objects created on the server side that will be used if the principal
components are to be plotted
Pooled method implemented using block method ("Parallel Algorithms for the Singular Value Decomposition." Berry et al. 2005). The `snp_subset` option uses gene regions that have been linked to ethnic groupings, it is suggested to use this option to optimize the computing time and get noise-less principal components.