ds.createRSE.RdCreate a RangedSummarizedExperiment from a RNAseq count table and a phenotypes table
ds.createRSE(
rnaseq,
phe,
annotCols = NULL,
newobj.name = NULL,
datasources = NULL
)character Name of the RNAseq table on the server
character Name of the phenotypes table on the server
character vector (default NULL) Columns of the counts table to be used as
annotation when creating the SummarizedExperiment. If NULL, biomaRt will be used to find
annotation using the first column of the counts table (EntrezID)
character (default NULL) Name to be assigned
on the server to the RangedSummarizedExperiment. If NULL the created RSE will
be assigned to a variable named 'RSE'
a list of DSConnection-class (default NULL) objects obtained after login
This function does not have an output. It creates (or overwrites) a data frame on the study server.
The RNAseq count table has to have the following structure:
- First column: Entrez identificator
- All the remaining columns: One col. per individual + annotation columns (no special
order required, they can even be mixed)
The phenotypes table has to have the following structure:
- First column: ID of the individuals. To match with the column names
of the RNAseq table
- All the remaining columns: One col. per phenotype