ds.make_valid_names.RdPasses the column names and the character variables through make.names, this creates
names without any special characters so there are no problems for accessing any columns or any category
when using the DataSHIELD parser.
ds.make_valid_names(x, newobj = NULL, datasources = NULL)character Name of the table on the server to be modified
character (default NULL) Name of the new object on the server. If NULL
the input object x will be overwritten
a list of DSConnection-class objects obtained after login.
If the datasources argument is not specified