ds.snptest.RdInterface to run SNPtest commands on a ssh connection (with SNPtest 2.5.2 installed)
ds.snptest(client, snptest.arguments, datasources = NULL)character Name of the ssh resource on the server
character SNPtest arguments, the leading "snptest" and trailing
"-o output.out" do not need to be provided, they are handled on the server side.
a list of DSConnection-class (default NULL) objects obtained after login
List containing:
- Results: Table of results (typical SNPtest output file)
- Output: Console output of the ssh query