ds.PCA()plotPCA.RdPlot the results of a ds.PCA()
plotPCA(object, group = NULL, xcomp = 1, ycomp = 2, datasources = NULL)numeric Principal component to plot on the X axis
numeric Principal component to plot on the Y axis
PCASNPS Object returned from ds.PCASNPS()
ggplot object