ds.PCASNPS()plotPCASNPS.RdPlot the results of a ds.PCASNPS()
plotPCASNPS(res, group = NULL, xcomp = 1, ycomp = 2, datasources = NULL)PCASNPS Object returned from ds.PCASNPS()
numeric Principal component to plot on the X axis
numeric Principal component to plot on the Y axis
ggplot object