pzPlot.RdP-Z plot
pzPlot(x, beta_column = "Est", se_column = "Est.SE", pval_column = "p.value")data.frame / list of data.frames (output of ds.GWAS) Single table of results or list of tables
(default output of ds.GWAS).
character (default "Est") Name of the column containing the betas.
character (default "Est.SE") Name of the column containing the SE.
character (default "p.value") Name of the column containing the p-values.
A ggplot object
Plot to reveal issues with beta estimates, standard errors and P values. The plots compare P values reported in the association GWAS with P values calculated from Z-statistics (P.ztest) derived from the reported beta and standard error. A study with no issues should show perfect concordance. It will generate a plot per study, where concordance of all the study SNPs will be displayed.