seNPlot.RdSE-N Plot
seNPlot(x, se_column = "Est.SE", n_column = "n.obs")list of data.frames (output of ds.GWAS) List of tables (default output of ds.GWAS).
character (default "Est.SE") Name of the column containing the SE.
character (default "n.obs") Name of the column containing the number of observations.
A ggplot object
Plot to reveal issues with trait transformations. A collection of studies with no issues will fall on a line.